package com.jjt.calc.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.calc.domain.TwinRecordAlarms;
import org.apache.ibatis.annotations.Options;

/**
 * 告警数据记录Mapper接口
 *
 * @author wukai
 * @date 2025-01-18
 */
public interface TwinRecordAlarmsMapper extends BaseMapper<TwinRecordAlarms>
{
    /**
     * 查询告警数据记录
     *
     * @param id 告警数据记录主键
     * @return 告警数据记录
     */
    public TwinRecordAlarms selectTwinRecordAlarmsById(Long id);

    /**
     * 查询告警数据记录列表
     *
     * @param twinRecordAlarms 告警数据记录
     * @return 告警数据记录集合
     */
    public List<TwinRecordAlarms> selectTwinRecordAlarmsList(TwinRecordAlarms twinRecordAlarms);

    /**
     * 新增告警数据记录
     *
     * @param twinRecordAlarms 告警数据记录
     * @return 结果
     */
    public int insertTwinRecordAlarms(TwinRecordAlarms twinRecordAlarms);

    /**
     * 修改告警数据记录
     *
     * @param twinRecordAlarms 告警数据记录
     * @return 结果
     */
    public int updateTwinRecordAlarms(TwinRecordAlarms twinRecordAlarms);

    /**
     * 删除告警数据记录
     *
     * @param id 告警数据记录主键
     * @return 结果
     */
    public int deleteTwinRecordAlarmsById(Long id);

    /**
     * 批量删除告警数据记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinRecordAlarmsByIds(Long[] ids);
}
